from django.contrib.auth import get_user_model
from django.db import models


class Post(models.Model):
    title = models.CharField(max_length=200, blank=False, null=False, verbose_name='Post title')
    pic = models.URLField(max_length=200, blank=True, null=True, verbose_name='Post pics')
    text = models.TextField(max_length=2000, blank=False, null=False, verbose_name='Post text')
    create = models.DateField(auto_now_add=True, verbose_name='Post create time')
    is_active = models.BooleanField(default=True, verbose_name='Is active')

    def __str__(self):
        return self.title


class Comment(models.Model):
    author = models.ForeignKey(get_user_model(), verbose_name='Comment author', related_name='comments', on_delete=models.CASCADE)
    post = models.ForeignKey('webapp.Post', verbose_name='Post', related_name='comments', on_delete=models.CASCADE)
    text = models.TextField(max_length=500, blank=False, null=False, verbose_name='Comment text')
    create = models.DateField(auto_now_add=True, verbose_name='Comment create time')

    def __str__(self):
        return self.author
